import os

__title__ = "botbuilder-sangam-dialogs-prompt"
__version__ = (
    os.environ["packageVersion"] if "packageVersion" in os.environ else "0.4.0"
)
__uri__ = "https://github.com/rvinothrajendran"
__author__ = "Bot Builder sangam"
__author_email__ = "r.vinoth@live.com"
__description__ = "Microsoft Bot Builder sangam dialogs prompts"
__summary__ = "A components is use for custom prompts to Microsoft Bot Builder SDK for Python"
__license__ = "MIT"



from setuptools import setup
import os

REQUIRES = [
   "botbuilder-core>=4.13.0",
   "botbuilder-schema>=4.13.0",
   "botbuilder-dialogs>=4.13.0",
]

root = os.path.abspath(os.path.dirname(__file__))

with open(os.path.join(root, "botbuilder", "sangam", "dialogs", "prompt","about.py")) as f:
    package_info = {}
    info = f.read()
    exec(info, package_info)

with open(os.path.join(root, "README.md"), encoding="utf-8") as f:
    long_description = f.read()

setup(
    name=package_info["__title__"],
    version=package_info["__version__"],
    url=package_info["__uri__"],
    author=package_info["__author__"],
    author_email=package_info["__author_email__"],
    description=package_info["__description__"],
    keywords="botbuilder bots ai botframework custom prompt",
    long_description=long_description,
    long_description_content_type="text/markdown",
    license=package_info["__license__"],
    packages=[
        "botbuilder.sangam.dialogs.prompt",
         "botbuilder.sangam.dialogs.prompt.adaptive"
    ],
    install_requires=REQUIRES,
    include_package_data=True,
    classifiers=[
        "Programming Language :: Python :: 3.8",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Development Status :: 3 - Alpha",
        "Topic :: Scientific/Engineering :: Artificial Intelligence",
    ],
)




from botbuilder.dialogs.prompts import Prompt, PromptOptions,PromptRecognizerResult
from botbuilder.core.turn_context import TurnContext
from botbuilder.schema import ActivityTypes
from typing import Callable, Dict
import json

class AdaptiveCardPrompt(Prompt):
    def __init__(self, dialog_id: str, validator: object = None):
        super().__init__(dialog_id, validator=validator)

    async def on_prompt(self, turn_context: TurnContext, state: Dict[str, object], options: PromptOptions, is_retry: bool):               
        if not turn_context:
            raise TypeError("turn_context Can’t  be none")
        if not options:
            raise TypeError("options Can’t  be none")

        if is_retry and options.retry_prompt is not None:
            await turn_context.send_activity(options.retry_prompt)
        else:
            if options.prompt is not None:
                await turn_context.send_activity(options.prompt)    
        
        return await super().on_prompt(turn_context, state, options, is_retry)

    async def on_recognize(self, turn_context: TurnContext, state: Dict[str, object], options: PromptOptions):
        if not turn_context:
            raise TypeError("turn_context cannt be none")

        if not turn_context.activity:
            raise TypeError("turn_context.activity cannt be none")
        
        if turn_context.activity.type == ActivityTypes.message:
            usertext = turn_context.activity.value
            if usertext is not None:
                result = self.IsValidJson(usertext)
            else:
                result = False

            prompt_result = PromptRecognizerResult()
            prompt_result.succeeded = result

            if result == True:
                prompt_result.value = usertext                
            else:
                prompt_result.error = "Invalid JSON"

            return prompt_result               

    def IsValidJson(self,jsonString):
        try:
            json_data = json.dumps(jsonString)
            json.loads(json_data)
        except ValueError:
            return False
        return True
